==> slat-0.2.3-py2.py3-none-any.whl: slat/log_util.py <==
"""
LogUtil integrates structured logging via structlog.
This also gives us the ability to bind key/vals for all log statements"""
import logging
import os
import sys
from typing import Dict

import structlog

# configured for JSON logging
# see: http://www.structlog.org/en/stable/standard-library.html#rendering-within-structlog
from structlog.threadlocal import clear_threadlocal, bind_threadlocal

structlog.configure(
    processors=[
        structlog.threadlocal.merge_threadlocal_context,
        # This performs the initial filtering, so we don't
        # evaluate e.g. DEBUG when unnecessary
        structlog.stdlib.filter_by_level,
        # Adds logger=module_name (e.g __main__)
        structlog.stdlib.add_logger_name,
        # Adds level=info, debug, etc.
        structlog.stdlib.add_log_level,
        # Performs the % string interpolation as expected
        structlog.stdlib.PositionalArgumentsFormatter(),
        # add ISO9601 stamp: e.g. 2019-11-06T19:53:41.189600Z
        structlog.processors.TimeStamper(fmt="iso"),
        # Include the stack when stack_info=True
        structlog.processors.StackInfoRenderer(),
        # Include the exception when exc_info=True
        # e.g log.exception() or log.warning(exc_info=True)'s behavior
        structlog.processors.format_exc_info,
        # Decodes the unicode values in any kv pairs
        structlog.processors.UnicodeDecoder(),
        structlog.processors.JSONRenderer(sort_keys=True)
    ],
    # Our "event_dict" is explicitly a dict
    # There's also structlog.threadlocal.wrap_dict(dict) in some examples
    # which keeps global context as well as thread locals
    context_class=dict,
    # Provides the logging.Logger for the underlaying log call
    logger_factory=structlog.stdlib.LoggerFactory(),
    # Provides predefined methods - log.debug(), log.info(), etc.
    wrapper_class=structlog.stdlib.BoundLogger,
    # Caching of our logger
    cache_logger_on_first_use=True,
)


class LogUtil:
    """

    We use threadlocal for binding values.  This keeps us from having to pass the logger object between functions
    see: https://www.structlog.org/en/stable/thread-local.html
    """

    @staticmethod
    def init_logger(env_var_name: str = 'LOG_LEVEL',
                    default_level: str = 'INFO') -> logging.Logger:
        """

        :param env_var_name: [optional] Looks for log level [DEBUG|INFO|...] set at this ENV var name
        :type env_var_name: str
        :param default_level: [optional, defaults to INFO] Run this level if env_var_name not found
        :type default_level: str
        :return:
        :rtype: Logging.Logger
        """

        # remove the Lambda build handles.
        # https://stackoverflow.com/questions/37703609/using-python-logging-with-aws-lambda
        root = logging.getLogger()
        if root.handlers:
            for handler in root.handlers:
                root.removeHandler(handler)

        log_level = os.getenv(env_var_name, default_level)
        logging.basicConfig(
            format="%(message)s",
            stream=sys.stdout,
            level=log_level.upper(),
        )
        log = structlog.getLogger()
        # @TODO gotta be a better way to do this??
        if os.getenv('TESTING_RUN', None):
            file_handler = logging.FileHandler('testing.log')
            log.addHandler(file_handler)
        return log

    @staticmethod
    def get_logger():
        """
        Get Logger.  Use this if you need access to logger outside of lambda handler file
        :return:
        :rtype:
        """
        return structlog.getLogger()

    @staticmethod
    def init_request(key_val: Dict[str, str]):
        """

        :param key_val:
        :type key_val: Dict[str, str]
        :return:
        :rtype: None
        """
        LogUtil.bind(key_val, clear_thread_local=True)

    @staticmethod
    def bind(key_val: Dict[str, str], clear_thread_local=False):
        """

        :param key_val:
        :type key_val: Dict[str, str]
        :param clear_thread_local:
        :type clear_thread_local: bool
        :return:
        :rtype: None
        """
        if clear_thread_local:
            LogUtil.clear_threadlocal()
        bind_threadlocal(**key_val)

    @staticmethod
    def clear_threadlocal():
        """

        :return:
        :rtype: None
        """
        clear_threadlocal()

==> slat-0.3.0-py2.py3-none-any.whl: slat/log_util.py <==
"""
LogUtil integrates structured logging via structlog.
This also gives us the ability to bind key/vals for all log statements

inspired by https://gist.github.com/impredicative/ed475ccdcf7759ea8db155f31b41b993
"""
import inspect
import logging
import os
import sys
from typing import Dict

import structlog
# configured for JSON logging
# see: http://www.structlog.org/en/stable/standard-library.html#rendering-within-structlog
from structlog.threadlocal import clear_threadlocal, bind_threadlocal


def _add_caller_info(logger, method_name, event_dict):  # pylint: disable=unused-argument
    # Typically skipped funcs: _add_caller_info, _process_event, _proxy_to_logger, _proxy_to_logger
    frame = inspect.currentframe()
    while frame:
        frame = frame.f_back
        module = frame.f_globals['__name__']
        if module.startswith('structlog.'):
            continue
        event_dict['_module'] = module
        event_dict['_lineno'] = frame.f_lineno
        event_dict['_func'] = frame.f_code.co_name
        return event_dict


structlog.configure(
    processors=[
        structlog.threadlocal.merge_threadlocal_context,
        # This performs the initial filtering, so we don't
        # evaluate e.g. DEBUG when unnecessary
        structlog.stdlib.filter_by_level,
        _add_caller_info,
        # Adds logger=module_name (e.g __main__)
        # structlog.stdlib.add_logger_name,
        # Adds level=info, debug, etc.
        # structlog.stdlib.add_log_level,
        # Performs the % string interpolation as expected
        structlog.stdlib.PositionalArgumentsFormatter(),
        # add ISO9601 stamp: e.g. 2019-11-06T19:53:41.189600Z
        structlog.processors.TimeStamper(fmt="iso"),
        # Include the stack when stack_info=True
        structlog.processors.StackInfoRenderer(),
        # Include the exception when exc_info=True
        # e.g log.exception() or log.warning(exc_info=True)'s behavior
        structlog.processors.format_exc_info,
        # Decodes the unicode values in any kv pairs
        structlog.processors.UnicodeDecoder(),
        structlog.processors.JSONRenderer(sort_keys=True)
    ],
    # Our "event_dict" is explicitly a dict
    # There's also structlog.threadlocal.wrap_dict(dict) in some examples
    # which keeps global context as well as thread locals
    context_class=dict,
    # Provides the logging.Logger for the underlaying log call
    logger_factory=structlog.stdlib.LoggerFactory(),
    # Provides predefined methods - log.debug(), log.info(), etc.
    wrapper_class=structlog.stdlib.BoundLogger,
    # Caching of our logger
    cache_logger_on_first_use=True,
)


class LogUtil:
    """

    We use threadlocal for binding values.  This keeps us from having to pass the logger object between functions
    see: https://www.structlog.org/en/stable/thread-local.html
    """

    @staticmethod
    def init_logger(env_var_name: str = 'LOG_LEVEL',
                    default_level: str = 'INFO') -> logging.Logger:
        """

        :param env_var_name: [optional] Looks for log level [DEBUG|INFO|...] set at this ENV var name
        :type env_var_name: str
        :param default_level: [optional, defaults to INFO] Run this level if env_var_name not found
        :type default_level: str
        :return:
        :rtype: Logging.Logger
        """

        # remove the Lambda build handles.
        # https://stackoverflow.com/questions/37703609/using-python-logging-with-aws-lambda
        root = logging.getLogger()
        if root.handlers:
            for handler in root.handlers:
                root.removeHandler(handler)

        log_level = os.getenv(env_var_name, default_level)
        logging.basicConfig(
            format="%(message)s",
            stream=sys.stdout,
            level=log_level.upper(),
        )

        return LogUtil.get_logger()

    @staticmethod
    def get_logger(name=None):
        """
        Get Logger.  Use this if you need access to logger outside of lambda handler file
        :return:
        :rtype:
        """
        if name is None:
            name = inspect.currentframe().f_back.f_globals['__name__']
        log = structlog.wrap_logger(logging.getLogger(name))
        if os.getenv('TESTING_RUN', None):
            file_handler = logging.FileHandler('testing.log')
            log.addHandler(file_handler)
        return log

    @staticmethod
    def init_request(key_val: Dict[str, str]):
        """

        :param key_val:
        :type key_val: Dict[str, str]
        :return:
        :rtype: None
        """
        LogUtil.bind(key_val, clear_thread_local=True)

    @staticmethod
    def bind(key_val: Dict[str, str], clear_thread_local=False):
        """

        :param key_val:
        :type key_val: Dict[str, str]
        :param clear_thread_local:
        :type clear_thread_local: bool
        :return:
        :rtype: None
        """
        if clear_thread_local:
            LogUtil.clear_threadlocal()
        bind_threadlocal(**key_val)

    @staticmethod
    def clear_threadlocal():
        """

        :return:
        :rtype: None
        """
        clear_threadlocal()
